socket_path

Function socket_path 

pub fn socket_path() -> Result<PathBuf, Error>
Get socket path for the spn daemon, returning an error if HOME is unavailable.

Use this function when you need to ensure a secure socket path. Returns an error instead of falling back to /tmp.

This is a convenience wrapper around SpnPaths::new()?.socket_file().